@@ -61,7 +61,7 @@ def input_credentials_if_unauthorized(func):
         for _ in range(LOGIN_RETRIES):
             user, password = self._user_io.request_login(self._remote.name, self.user)
             try:
-                token = self.authenticate(user, password)
+                token, _, _, _ = self.authenticate(user, password)
             except AuthenticationException:
                 if self.user is None:
                     self._user_io.out.error('Wrong user or password')
@@ -193,5 +193,5 @@ class ConanApiAuthManager(object):
             raise ConanException("Password contains not allowed symbols")
 
         # Store result in DB
-        update_localdb(self._localdb, user, token, self._remote, self._user_io.out)
-        return token
+        remote, prev_user, user = update_localdb(self._localdb, user, token, self._remote)
+        return token, remote, prev_user, user
